STShadows class

Box shadows used as-is in light and dark (not auto-flipped).

Constructors

STShadows({List<BoxShadow> sm = const [BoxShadow(color: Color(0x33000000), blurRadius: 4, offset: Offset(0, 1))], List<BoxShadow> md = const [BoxShadow(color: Color(0x3D000000), blurRadius: 8, offset: Offset(0, 2))], List<BoxShadow> lg = const [BoxShadow(color: Color(0x4D000000), blurRadius: 16, offset: Offset(0, 4))]})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg List<BoxShadow>
final
md List<BoxShadow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm List<BoxShadow>
final

Methods

copyWith({List<BoxShadow>? sm, List<BoxShadow>? md, List<BoxShadow>? lg}) STShadows
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited