STTheme class

Source of truth for look tokens. Project to ThemeData via light / dark.

Constructors

STTheme({required STColors colors, STRadius radius = const STRadius(), STShadows shadows = const STShadows(), STTypography typography = const STTypography(), STComponents components = const STComponents(), List<STExtra> extras = const []})
const

Properties

colors STColors
final
components STComponents
final
dark ThemeData
Dark ThemeData including STThemeExtension.
no setter
extras List<STExtra>
App-specific styles: extra buttons, cards, containers, and text roles.
final
hashCode int
The hash code for this object.
no setterinherited
light ThemeData
Light ThemeData including STThemeExtension.
no setter
radius STRadius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows STShadows
final
typography STTypography
final

Methods

copyWith({STColors? colors, STRadius? radius, STShadows? shadows, STTypography? typography, STComponents? components, List<STExtra>? extras}) STTheme
extensionFor(Brightness brightness) STThemeExtension
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Brightness brightness) STResolved
Resolved tokens for a brightness (without building full ThemeData).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited