STComponentIr class

Constructors

STComponentIr({STColorIr? fill, STColorIr? foreground, STColorIr? border, double? elevation, double? radius, bool? filled})
const

Properties

border STColorIr?
final
elevation double?
final
fill STColorIr?
final
filled bool?
final
foreground STColorIr?
final
hashCode int
The hash code for this object.
no setterinherited
isSet bool
no setter
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited