STDartTokens class

Names + kinds scanned from hand-written Dart (STTheme / STExtra).

Constructors

STDartTokens({String? variableName, List<STExtraIr> extras = const [], List<String> extraColors = const [], List<String> extraComponents = const []})
const

Properties

extraColors List<String>
final
extraComponents List<String>
final
extras List<STExtraIr>
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variableName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited