STDesignIr class

Parsed JSON design. No Flutter types — safe for dart run.

Constructors

STDesignIr({required String variableName, required String extensionName, required STColorsIr colors, String? partOf, STRadiusIr? radius, STTypographyIr? typography, STComponentsIr? components, List<STExtraIr> extras = const []})
const

Properties

colors → STColorsIr
final
components → STComponentsIr?
final
extensionName → String
final
extras → List<STExtraIr>
final
hashCode → int
The hash code for this object.
no setterinherited
partOf → String?
final
radius → STRadiusIr?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typography → STTypographyIr?
final
variableName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited