STExtraIr class

Constructors

STExtraIr({required String name, required STIrKind kind, STComponentIr style = const STComponentIr(), STTextTokenIr? text})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → STIrKind
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → STComponentIr
final
text → STTextTokenIr?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited