STParsedTheme class

Parsed design plus a runtime STTheme. Flutter-only (not used by the CLI).

Constructors

STParsedTheme({required STTheme theme, required STDesignIr ir})
const

Properties

extensionName String
no setter
hashCode int
The hash code for this object.
no setterinherited
ir STDesignIr
final
partOf String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme STTheme
final
variableName String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited