STRadiusIr class

Constructors

STRadiusIr({double? xs, double? sm, double? md, double? lg, double? xl})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSet → bool
no setter
lg → double?
final
md → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm → double?
final
xl → double?
final
xs → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited