STTextTokenIr class

Constructors

STTextTokenIr({double? fontSize, int? fontWeight, String? fontStyle, double? height, double? letterSpacing, STColorIr? color, String? colorName})
const

Properties

color → STColorIr?
final
colorName → String?
final
fontSize → double?
final
fontStyle → String?
final
fontWeight → int?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isSet → bool
no setter
letterSpacing → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited