STColorsIr class

Constructors

STColorsIr({required STColorIr primary, required STColorIr surface, required STColorIr background, required STColorIr text, STColorIr? secondary, STColorIr? border, STColorIr? divider, STColorIr? textSecondary, STColorIr? error, STColorIr? success, STColorIr? warning, STColorIr? info, Map<String, STColorIr> extra = const {}, Set<String> fields = const {}})
const

Properties

background STColorIr
final
border STColorIr?
final
divider STColorIr?
final
error STColorIr?
final
extra Map<String, STColorIr>
final
fields Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
info STColorIr?
final
primary STColorIr
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary STColorIr?
final
success STColorIr?
final
surface STColorIr
final
text STColorIr
final
textSecondary STColorIr?
final
warning STColorIr?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited