STComponentsIr class

Constructors

STComponentsIr({Map<String, STComponentIr> slots = const {}, Map<String, STComponentIr> extra = const {}})
const

Properties

extra Map<String, STComponentIr>
final
hashCode int
The hash code for this object.
no setterinherited
isSet bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slots Map<String, STComponentIr>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited