STTypographyIr class
Constructors
- STTypographyIr({String? fontFamily, STTextTokenIr? label, STTextTokenIr? sublabel, STTextTokenIr? description})
-
const
Properties
- description → STTextTokenIr?
-
final
- fontFamily → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → STTextTokenIr?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sublabel → STTextTokenIr?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited